---
type: slide
slideOptions:
  transition: slide
---

# 计算机网络基础

## 互联网是怎样工作的

---

# 概述

使用<a style="color: red">通俗易懂</a>的语言讲述

<span>- 互联网C/S结构和B/S结构的工作模式<!-- .element: class="fragment" --></span>

<span>- 网络中各种设备的具体作用<!-- .element: class="fragment" --></span>

<span>- 协议的功能和使用<!-- .element: class="fragment" --></span>

---

# 互联网的源和汇

<v-clicks>

互联网用以传输信息

互联网的**两端**

从**源**到**汇**

</v-clicks>

<!--
互联网是设备之间用以传输数据的的途径，一个数据包只能从一个设备发出到另一个设备，数据的源和汇都采用的统一的规则发送和接受数据，在一次通信中，一个设备一般既送出数据也接受数据，互联网在源和汇中一般会存在多个中转点，但我们不着重介绍，本课程中着重介绍源和汇是以何种格式交换和解析数据的
-->

---

# 客户端

<v-clicks>

从服务端获取资源

一般不会保持长期在线

一般不具有大量的储存空间和强大的计算能力

一般不具有固定的公网IP

</v-clicks>

---

# 服务端

<v-clicks>

储存互联网的资源

一般具有强大的计算和储存能力

一般具有固定的公网IP地址

一般保持24小时长期在线

</v-clicks>

<!--
客户端和服务端并没有严格的定义，一个设备给别人发东西，那么这个设备就能称之为服务端，一个设备接受数据，就能称之为客户端
-->

---

# IP地址

你家在哪？

<v-clicks>

IPv4格式为4字节

4,294,967,296  2^32

```text
111.111.111.111
```

- 互联网中一切目标都用IP来定位

- 门牌不够长写不下来

- 每一个联网的设备都至少拥有一个IP

- 中转设备一般有不止一个IP （联通两个网络）

- IPV6 `2001:0db8:02de:0000:0000:0000:0000:0e13`

</v-clicks>

<!--
这个格式非常的通用，数十年前的包放到现在依旧能够正常传播，每一个数据包一定都带有描述IP地址的数据，用以指定该数据包的来源和目的地，中间节点会依照对应的格式将该数据包转发到对应的节点传递下去，在互联网的设计中，每一个节点都遵守相同的规则，那么这个数据包就能传遍全球！中转设备如路由器
-->

---

# 私有IP地址

<v-clicks>

局域网中的IP地址

- A: `10.0.0.0 ~ 10.255.255.255`
- B: `172.16.0.0 ~ 172.31.255.255`
- C: `192.168.0.0 ~ 192.168.255.255`

在运营商的路由器中不存在路由目的地址

</v-clicks>

---

# 端口

抽象的力量

<v-clicks>

现状：

- 操作系统中有很多程序同时都想通讯

- 网络中有很多设备都想通讯

> 数据包送到家里的某个人

端口！

</v-clicks>

---

# 在浏览器中输入网址按下回车后发生了什么!

<v-clicks>

访问目标

- 服务器的地址

- 想要得到的数据

- 自己的地址

</v-clicks>

<!--
想要访问一个目标首先要知道目标在哪，然后就是要确定客户端想要得到什么数据，最后要附上自己的地址，以便于服务器将你想要的数据发给你
-->

---

## 1.获取到地址

<v-clicks>

DNS协议，解析域名

域名==IP地址

得到地址！

```
┌─────────┐          ┌────────────┐
│baidu.com├─────────►│39.156.69.79│
└─────────┘          └────────────┘
```

这是浏览器的工作

</v-clicks>

---

## 2.发送获取数据的请求

<v-clicks>

浏览器根据你输入的网址和刚刚得到的IP地址自动生成一个固定格式的请求发送给服务器

```
┌──────┐          ┌─────────┐
│Chrome├─────────►│baidu.com│
└──────┘          └─────────┘
```

- 该格式称为HTTP协议

</v-clicks>

---

## 3.服务器查找数据

<v-clicks>

接收到数据包解析，本质是文档，协议格式如下

互联网例子：

```
http:// # 标识协议开始，这里是http
http://baidu.com # baidu.com 标识主机名，这里我们访问百度的主机
http://baidu.com/map/index.html # /map/index.html 表示文件路径
```
给出另一个例子，访问本机文件：
```
file:///Users/vaala/Workdir/Temp/html/main.html
file:// 指file协议
主机名为空，访问的是自己
/Users/vaala/Workdir/Temp/html/main.html 为路径
```

</v-clicks>

---

## 4.服务器返回资源

<v-clicks>

资源=服务器查找到的资源+数据包的基础数据

```
┌─────────┐          ┌──────┐
│baidu.com├─────────►│Chrome│
└─────────┘          └──────┘
```

如果没有找到资源则会返回对应的错误

</v-clicks>

---

## 5.浏览器解析数据将其变为文档

<v-clicks>

得到的数据由浏览器根据html/css/js语法解析为对应的页面

这时候的工作都在客户端上进行

</v-clicks>

---

## 整个流程

<v-clicks>

```
                            ┌───────┐        /        ┌─────────┐
┌─────────────────┐         │       │ ──────────────► │baidu.com│
│http://baidu.com/│ ──────► │Chrome │                 │(x.x.x.x)│
└─────────────────┘         │       │ ◄────────────── │         │
                            └───────┘  balabalabala.. └─────────┘

                               ▲ │
                               │ │
                        x.x.x.x│ │baidu.com
                               │ │
                               │ ▼

                             ┌─────┐
                             │ DNS │
                             └─────┘
```

</v-clicks>

---

# 服务器接受请求

<v-clicks>

Python!

```bash
python3 -m http.server 8080
```
功能？
```python
from flask import Flask
app = Flask(__name__)
@app.route('/')
def index():
    return '<h1>Hello World</h1>'
if __name__ == '__main__':
    app.run()
```

</v-clicks>

---

# 前端与后端

<v-clicks>

浏览器与服务器

</v-clicks>

---

# 代理服务器

<v-clicks>

- 正向代理

- 反向代理

</v-clicks>

---

# 思考

<v-clicks>

利用前面提到的东西搞事情？

- DNS隧道

</v-clicks>